@@ -1,4 +1,4 @@
-<?PHP //$Id: block_recent_activity.php,v 1.6 2005/03/02 19:22:24 defacer Exp $
+<?PHP //$Id: block_recent_activity.php,v 1.8.4.1 2006/05/29 08:15:23 moodler Exp $
 
 class block_recent_activity extends block_base {
     function init() {
@@ -7,6 +7,7 @@ class block_recent_activity extends block_base {
     }
 
     function get_content() {
+        global $COURSE;
 
         if ($this->content !== NULL) {
             return $this->content;
@@ -21,16 +22,17 @@ class block_recent_activity extends block_base {
         $this->content->text = '';
         $this->content->footer = '';
 
-        $course = get_record('course', 'id', $this->instance->pageid);
-
         // Slightly hacky way to do it but...
         ob_start();
-        print_recent_activity($course);
+        print_recent_activity($COURSE);
         $this->content->text = ob_get_contents();
         ob_end_clean();
 
         return $this->content;
     }
-}
 
+    function applicable_formats() {
+        return array('all' => true, 'my' => false);
+    }
+}
 ?>
