@@ -1,4 +1,4 @@
-<?php // $Id: event.php,v 1.42.2.5 2005/10/24 17:15:30 defacer Exp $
+<?php // $Id: event.php,v 1.50.2.5 2006/09/17 17:33:42 gustav_delius Exp $
 
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
@@ -50,10 +50,13 @@
         redirect(CALENDAR_URL.'view.php?view=upcoming');
     }
 
-    $action    = required_param('action', PARAM_ALPHA);
-    $eventid   = optional_param('id', 0, PARAM_INT);
+    $action = required_param('action', PARAM_ALPHA);
+    $eventid = optional_param('id', 0, PARAM_INT);
     $eventtype = optional_param('type', 'select', PARAM_ALPHA);
     $urlcourse = optional_param('course', 0, PARAM_INT);
+    $cal_y = optional_param('cal_y');
+    $cal_m = optional_param('cal_m');
+    $cal_d = optional_param('cal_d');
 
     if(!$site = get_site()) {
         redirect($CFG->wwwroot.'/'.$CFG->admin.'/index.php');
@@ -113,7 +116,7 @@
 
             if($form = data_submitted()) {
 
-                $form->name = clean_text(strip_tags($form->name,'<lang><span>'));
+                $form->name = clean_param(strip_tags($form->name,'<lang><span>'), PARAM_CLEAN);
 
                 $form->timestart = make_timestamp($form->startyr, $form->startmon, $form->startday, $form->starthr, $form->startmin);
                 if($form->duration == 1) {
@@ -180,7 +183,7 @@
             $form = data_submitted();
             if(!empty($form) && $form->type == 'defined') {
 
-                $form->name = strip_tags($form->name, '<lang>');  // Strip all tags but <lang>
+                $form->name = clean_text(strip_tags($form->name, '<lang><span>'));
 
                 $form->timestart = make_timestamp($form->startyr, $form->startmon, $form->startday, $form->starthr, $form->startmin);
                 if($form->duration == 1) {
@@ -230,7 +233,6 @@
                             add_to_log($form->courseid, 'calendar', 'add', 'event.php?action=edit&amp;id='.$eventid, stripslashes($form->name));
                         }
                     }
-
                     // OK, now redirect to day view
                     redirect(CALENDAR_URL.'view.php?view=day&cal_d='.$form->startday.'&cal_m='.$form->startmon.'&cal_y='.$form->startyr);
                 }
@@ -365,23 +367,18 @@
         break;
 
         case 'new':
-            optional_variable($_GET['cal_y']);
-            optional_variable($_GET['cal_m']);
-            optional_variable($_GET['cal_d']);
-            optional_variable($form->timestart, -1);
-
-            if($_GET['cal_y'] && $_GET['cal_m'] && $_GET['cal_d'] && checkdate($_GET['cal_m'], $_GET['cal_d'], $_GET['cal_y'])) {
-                $form->timestart = make_timestamp($_GET['cal_y'], $_GET['cal_m'], $_GET['cal_d'], 0, 0, 0);
+            if($cal_y && $cal_m && $cal_d && checkdate($cal_m, $cal_d, $cal_y)) {
+                $form->timestart = make_timestamp($cal_y, $cal_m, $cal_d, 0, 0, 0);
             }
-            else if($_GET['cal_y'] && $_GET['cal_m'] && checkdate($_GET['cal_m'], 1, $_GET['cal_y'])) {
-                if($_GET['cal_y'] == $now['year'] && $_GET['cal_m'] == $now['mon']) {
-                    $form->timestart = make_timestamp($_GET['cal_y'], $_GET['cal_m'], $now['mday'], 0, 0, 0);
+            else if($cal_y && $cal_m && checkdate($cal_m, 1, $cal_y)) {
+                if($cal_y == $now['year'] && $cal_m == $now['mon']) {
+                    $form->timestart = make_timestamp($cal_y, $cal_m, $now['mday'], 0, 0, 0);
                 }
                 else {
-                    $form->timestart = make_timestamp($_GET['cal_y'], $_GET['cal_m'], 1, 0, 0, 0);
+                    $form->timestart = make_timestamp($cal_y, $cal_m, 1, 0, 0, 0);
                 }
             }
-            if($form->timestart < 0) {
+            if(!isset($form->timestart) or $form->timestart < 0) {
                 $form->timestart = time();
             }
 
@@ -487,15 +484,20 @@
             echo '<div class="header">'.get_string('newevent', 'calendar').$header.'</div>';
 
             if($eventtype == 'select') {
-                $defaultcourse = $SESSION->cal_course_referer;
-                if(isteacheredit($defaultcourse, $USER->id)) {
-                    $defaultgroup = $groupid = 0;
+                $courseid = optional_param('courseid', $SESSION->cal_course_referer, PARAM_INT);
+                if ($courseid == 0) { // workaround by Dan for bug #6130
+                    $courseid = SITEID;
                 }
-                else {
-                    $defaultgroup = user_group($defaultcourse, $USER->id);
-                    $groupid      = optional_param('groupid',  $defaultgroup->id, PARAM_INT);
+                if (!$course = get_record('course', 'id', $courseid)) {
+                    error('Incorrect course ID');
                 }
-                $courseid = optional_param('courseid', $defaultcourse, PARAM_INT);
+                if ($groupmode = groupmode($course)) {   // Groups are being used
+                    $changegroup = optional_param('group', -1, PARAM_INT);
+                    $groupid = get_and_set_current_group($course, $groupmode, $changegroup);
+                } else {
+                    $groupid = 0;
+                }
+
                 echo '<h2>'.get_string('eventkind', 'calendar').':</h2>';
                 echo '<div id="selecteventtype">';
                 include('event_select.html');
