@@ -1,4 +1,4 @@
-<?php // $Id: view.php,v 1.40.2.8 2004/12/02 19:51:29 defacer Exp $
+<?php // $Id: view.php,v 1.69.8.1 2006/07/17 21:07:06 skodak Exp $
 
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
@@ -44,41 +44,41 @@
     require_once($CFG->dirroot.'/course/lib.php');
     require_once($CFG->dirroot.'/calendar/lib.php');
 
-    optional_variable($_GET['course'], 0);
+    $course = optional_param('course', 0);
+    $view = optional_param('view', 'upcoming');
+    $day  = optional_param('cal_d', 0, PARAM_INT);
+    $mon  = optional_param('cal_m', 0, PARAM_INT);
+    $yr   = optional_param('cal_y', 0, PARAM_INT);
 
     if(!$site = get_site()) {
         redirect($CFG->wwwroot.'/'.$CFG->admin.'/index.php');
     }
 
+    if ($CFG->forcelogin) {
+        require_login();
+    }
+
     //add_to_log($course->id, "course", "view", "view.php?id=$course->id", "$course->id");
     $now = usergetdate(time());
     $pagetitle = '';
 
     $nav = calendar_get_link_tag(get_string('calendar', 'calendar'), CALENDAR_URL.'view.php?view=upcoming&amp;', $now['mday'], $now['mon'], $now['year']);
 
-    $view = optional_param('view', 'upcoming');
-    $day = optional_param('cal_d', 0, PARAM_INT);
-    $mon = optional_param('cal_m', 0, PARAM_INT);
-    $yr  = optional_param('cal_y', 0, PARAM_INT);
     
     if(!checkdate($mon, $day, $yr)) {
         $day = intval($now['mday']);
         $mon = intval($now['mon']);
         $yr = intval($now['year']);
     }
-    $time = mktime(0, 0, 0, $mon, $day, $yr);
+    $time = make_timestamp($yr, $mon, $day);
 
     switch($view) {
         case 'day':
-            $text = strftime(get_string('strftimedate'), $time);
-            if($text[0] == '0') {
-                $text = substr($text, 1);
-            }
-            $nav .= ' -> '.$text;
+            $nav .= ' -> '.userdate($time, get_string('strftimedate'));
             $pagetitle = get_string('dayview', 'calendar');
         break;
         case 'month':
-            $nav .= ' -> '.strftime(get_string('strftimemonthyear'), $time);
+            $nav .= ' -> '.userdate($time, get_string('strftimemonthyear'));
             $pagetitle = get_string('detailedmonthview', 'calendar');
         break;
         case 'upcoming':
@@ -87,16 +87,16 @@
     }
 
     // If a course has been supplied in the URL, change the filters to show that one
-    if (!empty($_GET['course'])) {
-        if (is_numeric($_GET['course']) && $_GET['course'] > 0 && record_exists('course', 'id', $_GET['course'])) {
-            if ($_GET['course'] == 1) {
+    if (!empty($course)) {
+        if ($course = get_record('course', 'id', $course)) {
+            if ($course->id == SITEID) {
                 // If coming from the home page, show all courses
                 $SESSION->cal_courses_shown = calendar_get_default_courses(true);
                 calendar_set_referring_course(0);
 
             } else {
                 // Otherwise show just this one
-                $SESSION->cal_courses_shown = intval($_GET['course']);
+                $SESSION->cal_courses_shown = $course->id;
                 calendar_set_referring_course($SESSION->cal_courses_shown);
             }
         }
@@ -112,11 +112,14 @@
 
     // Let's see if we are supposed to provide a referring course link
     // but NOT for the "main page" course
-    if ($SESSION->cal_course_referer > 1 &&
+    if ($SESSION->cal_course_referer != SITEID &&
        ($shortname = get_field('course', 'shortname', 'id', $SESSION->cal_course_referer)) !== false) {
         // If we know about the referring course, show a return link and ALSO require login!
         require_login();
         $nav = '<a href="'.$CFG->wwwroot.'/course/view.php?id='.$SESSION->cal_course_referer.'">'.$shortname.'</a> -> '.$nav;
+        if (empty($course)) {
+            $course = get_record('course', 'id', $SESSION->cal_course_referer); // Useful to have around
+        }
     }
 
     $strcalendar = get_string('calendar', 'calendar');
@@ -124,17 +127,17 @@
 
     // Print title and header
     print_header("$site->shortname: $strcalendar: $pagetitle", $strcalendar, $nav,
-                 '', '', true, $prefsbutton, '<p class="logininfo">'.user_login_string($site).'</p>');
+                 '', '', true, $prefsbutton, user_login_string($site));
 
     echo calendar_overlib_html();
 
     // Layout the whole page as three big columns.
-    echo '<table border="0" cellpadding="3" cellspacing="0" width="100%">';
-    echo '<tr style="vertical-align: top;">';
+    echo '<table id="calendar">';
+    echo '<tr>';
 
     // START: Main column
 
-    echo '<td style="vertical-align: top; width: 100%;">';
+    echo '<td class="maincalendar">';
 
     switch($view) {
         case 'day':
@@ -153,24 +156,28 @@
     // END: Main column
 
     // START: Last column (3-month display)
-    echo '<td style="vertical-align: top; width: 180px;">';
-    print_side_block_start(get_string('monthlyview', 'calendar'));
+    echo '<td class="sidecalendar">';
+    echo '<div class="header">'.get_string('monthlyview', 'calendar').'</div>';
+
     list($prevmon, $prevyr) = calendar_sub_month($mon, $yr);
     list($nextmon, $nextyr) = calendar_add_month($mon, $yr);
     $getvars = 'cal_d='.$day.'&amp;cal_m='.$mon.'&amp;cal_y='.$yr; // For filtering
+
+    echo '<div class="filters">';
     echo calendar_filter_controls($view, $getvars);
-    echo '<p>';
+    echo '</div>';
+
+    echo '<div class="minicalendarblock">';
     echo calendar_top_controls('display', array('m' => $prevmon, 'y' => $prevyr));
     echo calendar_get_mini($courses, $groups, $users, $prevmon, $prevyr);
-    echo '</p><p>';
+    echo '</div><div class="minicalendarblock">';
     echo calendar_top_controls('display', array('m' => $mon, 'y' => $yr));
     echo calendar_get_mini($courses, $groups, $users, $mon, $yr);
-    echo '</p><p>';
+    echo '</div><div class="minicalendarblock">';
     echo calendar_top_controls('display', array('m' => $nextmon, 'y' => $nextyr));
     echo calendar_get_mini($courses, $groups, $users, $nextmon, $nextyr);
-    echo '</p>';
-    print_side_block_end();
-    print_spacer(1, 180);
+    echo '</div>';
+
     echo '</td>';
 
     echo '</tr></table>';
@@ -180,7 +187,7 @@
 
 
 function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
-    global $CFG, $THEME, $USER;
+    global $CFG, $USER;
 
     if (!checkdate($m, $d, $y)) {
         $now = usergetdate(time());
@@ -194,13 +201,10 @@ function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
 
     $events = calendar_get_upcoming($courses, $groups, $users, 1, 100, $starttime);
 
-    // New event button
-    if (empty($USER->id) || isguest()) {
-        $text = get_string('dayview', 'calendar').': '.calendar_course_filter_selector($getvars);
-    } else {
-        $text = '<div style="float: left;">'.get_string('dayview', 'calendar').': '.
-                calendar_course_filter_selector($getvars).'</div><div style="float: right;">';
-        $text.= '<form style="display: inline;" action="'.CALENDAR_URL.'event.php" method="get">';
+    $text = '';
+    if (!isguest() && !empty($USER->id)) {
+        $text.= '<div class="buttons">';
+        $text.= '<form action="'.CALENDAR_URL.'event.php" method="get">';
         $text.= '<input type="hidden" name="action" value="new" />';
         $text.= '<input type="hidden" name="cal_d" value="'.$d.'" />';
         $text.= '<input type="hidden" name="cal_m" value="'.$m.'" />';
@@ -209,15 +213,20 @@ function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
         $text.= '</form></div>';
     }
 
-    print_side_block_start($text, array('class' => 'mycalendar'));
-    echo '<p>'.calendar_top_controls('day', array('d' => $d, 'm' => $m, 'y' => $y)).'</p>';
+    $text .= get_string('dayview', 'calendar').': '.calendar_course_filter_selector($getvars);
+
+    echo '<div class="header">'.$text.'</div>';
+
+    echo '<div class="controls">'.calendar_top_controls('day', array('d' => $d, 'm' => $m, 'y' => $y)).'</div>';
 
     if (empty($events)) {
         // There is nothing to display today.
-        echo '<p style="text-align: center;">'.get_string('daywithnoevents', 'calendar').'</p>';
+        echo '<h3>'.get_string('daywithnoevents', 'calendar').'</h3>';
 
     } else {
 
+        echo '<div class="eventlist">';
+
         $underway = array();
 
         // First, print details about events that start today
@@ -243,19 +252,20 @@ function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
 
         // Then, show a list of all events that just span this day
         if (!empty($underway)) {
-            echo '<p style="text-align: center;"><strong>'.get_string('spanningevents', 'calendar').':</strong></p>';
+            echo '<h3>'.get_string('spanningevents', 'calendar').':</h3>';
             foreach ($underway as $event) {
                 $event->time = calendar_format_event_time($event, time(), '', false);
                 calendar_print_event($event);
             }
         }
-    }
 
-    print_side_block_end();
+        echo '</div>';
+
+    }
 }
 
 function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
-    global $CFG, $SESSION, $USER;
+    global $CFG, $SESSION, $USER, $CALENDARDAYS;
     global $day, $mon, $yr;
 
     $getvars = 'from=month&amp;cal_d='.$day.'&amp;cal_m='.$mon.'&amp;cal_y='.$yr; // For filtering
@@ -315,13 +325,9 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
     // Extract information: events vs. time
     calendar_events_by_day($events, $m, $y, $eventsbyday, $durationbyday, $typesbyday);
 
-    // New event button
-    if(empty($USER->id) || isguest()) {
-        $text = get_string('detailedmonthview', 'calendar').': '.calendar_course_filter_selector($getvars);
-    }
-    else {
-        $text = '<div style="float: left;">'.get_string('detailedmonthview', 'calendar').': '.calendar_course_filter_selector($getvars).'</div><div style="float: right;">';
-        $text.= '<form style="display: inline;" action="'.CALENDAR_URL.'event.php" method="get">';
+    $text = '';
+    if(!isguest() && !empty($USER->id)) {
+        $text.= '<div class="buttons"><form action="'.CALENDAR_URL.'event.php" method="get">';
         $text.= '<input type="hidden" name="action" value="new" />';
         $text.= '<input type="hidden" name="cal_m" value="'.$m.'" />';
         $text.= '<input type="hidden" name="cal_y" value="'.$y.'" />';
@@ -329,22 +335,25 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         $text.= '</form></div>';
     }
 
-    print_side_block_start($text, array('class' => 'mycalendar'));
+    $text .= get_string('detailedmonthview', 'calendar').': '.calendar_course_filter_selector($getvars);
 
+    echo '<div class="header">'.$text.'</div>';
+
+    echo '<div class="controls">';
     echo calendar_top_controls('month', array('m' => $m, 'y' => $y));
+    echo '</div>';
 
     // Start calendar display
-    echo '<table class="calendarmonth"><thead><tr>'; // Begin table. First row: day names
+    echo '<table class="calendarmonth"><tr class="weekdays">'; // Begin table. First row: day names
 
     // Print out the names of the weekdays
-    $days = array('sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday');
     for($i = $display->minwday; $i <= $display->maxwday; ++$i) {
         // This uses the % operator to get the correct weekday no matter what shift we have
         // applied to the $display->minwday : $display->maxwday range from the default 0 : 6
-        echo '<td class="calendarheader">'.get_string($days[$i % 7], 'calendar').'</td>';
+        echo '<th>'.get_string($CALENDARDAYS[$i % 7], 'calendar').'</th>';
     }
 
-    echo '</tr></thead><tbody><tr>'; // End of day names; prepare for day numbers
+    echo '</tr><tr>'; // End of day names; prepare for day numbers
 
     // For the table display. $week is the row; $dayweek is the column.
     $week = 1;
@@ -368,9 +377,9 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         $cell = '';
         $dayhref = calendar_get_link_href(CALENDAR_URL.'view.php?view=day&amp;', $day, $m, $y);
 
-        if($dayweek % 7 == 0 || $dayweek % 7 == 6) {
+        if(CALENDAR_WEEKEND & (1 << ($dayweek % 7))) {
             // Weekend. This is true no matter what the exact range is.
-            $class = 'cal_weekend';
+            $class = 'weekend';
         }
         else {
             // Normal working day.
@@ -380,16 +389,16 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         // Special visual fx if an event is defined
         if(isset($eventsbyday[$day])) {
             if(isset($typesbyday[$day]['startglobal'])) {
-                $class .= ' cal_event_global';
+                $class .= ' event_global';
             }
             else if(isset($typesbyday[$day]['startcourse'])) {
-                $class .= ' cal_event_course';
+                $class .= ' event_course';
             }
             else if(isset($typesbyday[$day]['startgroup'])) {
-                $class .= ' cal_event_group';
+                $class .= ' event_group';
             }
             else if(isset($typesbyday[$day]['startuser'])) {
-                $class .= ' cal_event_user';
+                $class .= ' event_user';
             }
             if(count($eventsbyday[$day]) == 1) {
                 $title = get_string('oneevent', 'calendar');
@@ -397,29 +406,29 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
             else {
                 $title = get_string('manyevents', 'calendar', count($eventsbyday[$day]));
             }
-            $cell = '<strong><a href="'.$dayhref.'" title="'.$title.'">'.$day.'</a></strong>';
+            $cell = '<div class="day"><a href="'.$dayhref.'" title="'.$title.'">'.$day.'</a></div>';
         }
         else {
-            $cell = $day;
+            $cell = '<div class="day">'.$day.'</div>';
         }
 
         // Special visual fx if an event spans many days
         if(isset($typesbyday[$day]['durationglobal'])) {
-            $class .= ' cal_duration_global';
+            $class .= ' duration_global';
         }
         else if(isset($typesbyday[$day]['durationcourse'])) {
-            $class .= ' cal_duration_course';
+            $class .= ' duration_course';
         }
         else if(isset($typesbyday[$day]['durationgroup'])) {
-            $class .= ' cal_duration_group';
+            $class .= ' duration_group';
         }
         else if(isset($typesbyday[$day]['durationuser'])) {
-            $class .= ' cal_duration_user';
+            $class .= ' duration_user';
         }
 
         // Special visual fx for today
         if($display->thismonth && $day == $d) {
-            $class .= ' cal_today';
+            $class .= ' today';
         }
 
         // Just display it
@@ -429,17 +438,18 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         echo '<td'.$class.'>'.$cell;
 
         if(isset($eventsbyday[$day])) {
-            echo '<table>';
+            echo '<ul class="events-new">';
             foreach($eventsbyday[$day] as $eventindex) {
-                echo '<tr><td style="vertical-align: top; width: 10px;"><strong>&middot;</strong></td>';
-                echo '<td style="width: 100%;"><a href="'.$dayhref.'">'.$events[$eventindex]->name.'</a></td></tr>';
+                echo '<li><a href="'.$dayhref.'">'.format_string($events[$eventindex]->name,true).'</a></li>';
             }
-            echo '</table>';
+            echo '</ul>';
         }
         if(isset($durationbyday[$day])) {
+            echo '<ul class="events-underway">';
             foreach($durationbyday[$day] as $eventindex) {
-                echo '<div class="dimmed_text">('.$events[$eventindex]->name.')</div>';
+                echo '<li>['.format_string($events[$eventindex]->name,true).']</li>';
             }
+            echo '</ul>';
         }
         echo "</td>\n";
     }
@@ -448,18 +458,16 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
     for($i = $dayweek; $i <= $display->maxwday; ++$i) {
         echo '<td>&nbsp;</td>';
     }
-    echo "</tr>\n</tbody>\n"; // Last row ends
+    echo "</tr>\n"; // Last row ends
 
-    echo "</table>\n<br />\n"; // Tabular display of days ends
+    echo "</table>\n"; // Tabular display of days ends
 
     // OK, now for the filtering display
-    echo '<table class="cal_filters">';
-    echo '<tbody>';
-    echo '<tr>';
+    echo '<div class="filters"><table><tr>';
 
     // Global events
     if($SESSION->cal_show_global) {
-        echo '<td class="cal_event_global" style="width: 8px;"></td><td><strong>'.get_string('globalevents', 'calendar').':</strong> ';
+        echo '<td class="event_global" style="width: 8px;"></td><td><strong>'.get_string('globalevents', 'calendar').':</strong> ';
         echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showglobal&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
     }
     else {
@@ -469,7 +477,7 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
 
     // Course events
     if(!empty($SESSION->cal_show_course)) {
-        echo '<td class="cal_event_course" style="width: 8px;"></td><td><strong>'.get_string('courseevents', 'calendar').':</strong> ';
+        echo '<td class="event_course" style="width: 8px;"></td><td><strong>'.get_string('courseevents', 'calendar').':</strong> ';
         echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showcourses&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
     }
     else {
@@ -483,7 +491,7 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         echo '<tr>';
         // Group events
         if($SESSION->cal_show_groups) {
-            echo '<td class="cal_event_group" style="width: 8px;"></td><td><strong>'.get_string('groupevents', 'calendar').':</strong> ';
+            echo '<td class="event_group" style="width: 8px;"></td><td><strong>'.get_string('groupevents', 'calendar').':</strong> ';
             echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showgroups&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
         }
         else {
@@ -492,7 +500,7 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         }
         // User events
         if($SESSION->cal_show_user) {
-            echo '<td class="cal_event_user" style="width: 8px;"></td><td><strong>'.get_string('userevents', 'calendar').':</strong> ';
+            echo '<td class="event_user" style="width: 8px;"></td><td><strong>'.get_string('userevents', 'calendar').':</strong> ';
             echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showuser&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
         }
         else {
@@ -502,8 +510,7 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         echo "</tr>\n";
     }
 
-    echo '<tbody></table><br />';
-    print_side_block_end();
+    echo '</table></div>';
 }
 
 function calendar_show_upcoming_events($courses, $groups, $users, $futuredays, $maxevents) {
@@ -511,13 +518,11 @@ function calendar_show_upcoming_events($courses, $groups, $users, $futuredays, $
 
     $events = calendar_get_upcoming($courses, $groups, $users, $futuredays, $maxevents);
 
-    // New event button
-    if(empty($USER->id) || isguest()) {
-        $text = get_string('upcomingevents', 'calendar').': '.calendar_course_filter_selector('from=upcoming');
+    $text = '';
 
-    } else {
-        $text = '<div style="float: left;">'.get_string('upcomingevents', 'calendar').': '.calendar_course_filter_selector('from=upcoming').'</div><div style="float: right;">';
-        $text.= '<form style="display: inline;" action="'.CALENDAR_URL.'event.php" method="get">';
+    if(!isguest() && !empty($USER->id)) {
+        $text.= '<div class="buttons">';
+        $text.= '<form action="'.CALENDAR_URL.'event.php" method="get">';
         $text.= '<input type="hidden" name="action" value="new" />';
         /*
         $text.= '<input type="hidden" name="cal_m" value="'.$m.'" />';
@@ -527,74 +532,21 @@ function calendar_show_upcoming_events($courses, $groups, $users, $futuredays, $
         $text.= '</form></div>';
     }
 
-    print_side_block_start($text, array('class' => 'mycalendar'));
+    $text .= get_string('upcomingevents', 'calendar').': '.calendar_course_filter_selector('from=upcoming');
+
+    echo '<div class="header">'.$text.'</div>';
+
     if ($events) {
+        echo '<div class="eventlist">';
         foreach ($events as $event) {
             calendar_print_event($event);
         }
+        echo '</div>';
     } else {
-        echo '<br />';
         print_heading(get_string('noupcomingevents', 'calendar'));
     }
-    print_side_block_end();
 }
 
-
-function calendar_print_event($event) {
-    global $CFG, $THEME, $USER;
-
-    static $strftimetime;
-
-    echo '<table border="0" cellpadding="3" cellspacing="0" class="eventfull" width="100%">';
-    echo "<tr><td bgcolor=\"$THEME->cellcontent2\" class=\"eventfullpicture\" width=\"32\" valign=\"top\">";
-    if (!empty($event->icon)) {
-        echo $event->icon;
-    } else {
-        print_spacer(16,16);
-    }
-    echo '</td>';
-    echo "<td bgcolor=\"$THEME->cellheading\" class=\"eventfullheader\" width=\"100%\">";
-
-    if (!empty($event->referer)) {
-        echo '<span style="float:left;" class="calendarreferer">'.$event->referer.' </span>';
-    } else {
-        echo '<span style="float:left;" class="cal_event">'.$event->name."</span>";
-    }
-    if (!empty($event->courselink)) {
-        echo '<br /><span style="float:left; font-size: 0.8em;">'.$event->courselink.' </span>';
-    }
-    if (!empty($event->time)) {
-        echo '<span style="float:right;" class="cal_event_date">'.$event->time.'</span>';
-    } else {
-        echo '<span style="float:right;" class="cal_event_date">'.calendar_time_representation($event->timestart).'</span>';
-    }
-
-    echo "</td></tr>";
-    echo "<tr><td bgcolor=\"$THEME->cellcontent2\" valign=\"top\" class=\"eventfullside\" width=\"32\">&nbsp;</td>";
-    echo "<td bgcolor=\"$THEME->cellcontent\" class=\"eventfullmessage\">\n";
-    echo format_text($event->description, FORMAT_HTML);
-    if (calendar_edit_event_allowed($event)) {
-        echo '<div align="right">';
-        if (empty($event->cmid)) {
-            $editlink   = CALENDAR_URL.'event.php?action=edit&amp;id='.$event->id;
-            $deletelink = CALENDAR_URL.'event.php?action=delete&amp;id='.$event->id;
-        } else {
-            $editlink   = $CFG->wwwroot.'/course/mod.php?update='.$event->cmid.'&amp;return=true&amp;sesskey='.$USER->sesskey;
-            $deletelink = $CFG->wwwroot.'/course/mod.php?delete='.$event->cmid.'&amp;sesskey='.$USER->sesskey;;
-        }
-        echo ' <a href="'.$editlink.'"><img
-                  src="'.$CFG->pixpath.'/t/edit.gif" alt="'.get_string('tt_editevent', 'calendar').'"
-                  title="'.get_string('tt_editevent', 'calendar').'" /></a>';
-        echo ' <a href="'.$deletelink.'"><img
-                  src="'.$CFG->pixpath.'/t/delete.gif" alt="'.get_string('tt_deleteevent', 'calendar').'"
-                  title="'.get_string('tt_deleteevent', 'calendar').'" /></a>';
-        echo '</div>';
-    }
-    echo "</td></tr>\n</table><br />\n\n";
-
-}
-
-
 function calendar_course_filter_selector($getvars = '') {
     global $USER, $SESSION;
 
@@ -602,15 +554,15 @@ function calendar_course_filter_selector($getvars = '') {
         return '';
     }
 
-    if (isadmin()) {
+    if (isadmin() && !empty($CFG->calendar_adminseesall)) {
         $courses = get_courses('all', 'c.shortname','c.id,c.shortname');
     } else {
         $courses = get_my_courses($USER->id, 'shortname');
     }
 
-    unset($courses[1]);
+    unset($courses[SITEID]);
 
-    $courseoptions[1] = get_string('fulllistofcourses');
+    $courseoptions[SITEID] = get_string('fulllistofcourses');
     foreach ($courses as $course) {
         $courseoptions[$course->id] = $course->shortname;
     }
@@ -621,10 +573,8 @@ function calendar_course_filter_selector($getvars = '') {
         $selected = '';
     }
 
-    $form = popup_form(CALENDAR_URL.'set.php?var=setcourse&amp;'.$getvars.'&amp;id=',
+    return popup_form(CALENDAR_URL.'set.php?var=setcourse&amp;'.$getvars.'&amp;id=',
                        $courseoptions, 'cal_course_flt', $selected, '', '', '', true);
-
-    return str_replace('<form', '<form style="display: inline;"', $form);
 }
 
 ?>
