@@ -1,7 +1,7 @@
-<?php // $Id: editquestion.php,v 1.1 2006/03/24 21:21:59 gustav_delius Exp $
+<?php // $Id: editquestion.php,v 1.1.2.1 2006/07/18 15:27:51 tjhunt Exp $
 
     if (!empty($options->answers)) {
-        $answersraw = get_records_list("question_answers", "id", $options->answers);
+        $answersraw = get_records_list('question_answers', 'id', $options->answers);
 
     }
 
@@ -13,10 +13,10 @@
     }
 
     $yesnooptions = array();
-    $yesnooptions[0] = get_string("no");
-    $yesnooptions[1] = get_string("yes");
+    $yesnooptions[0] = get_string('no');
+    $yesnooptions[1] = get_string('yes');
 
-    print_heading_with_help(get_string("editingmissingtype", "quiz"), "multichoice", "quiz");
+    print_heading(get_string('warningmissingtype', 'quiz'));
     require("$CFG->dirroot/question/type/missingtype/editquestion.html");
 
 ?>
